==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescription } from "./WebFilteringOperationDescription";
/**
 * @hidden
 */
var WebFilteringOperationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringOperationDescriptionMetadata, _super);
    function WebFilteringOperationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringOperationDescriptionMetadata.b = function (a) {
        if (WebFilteringOperationDescriptionMetadata.a == null) {
            WebFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringOperationDescriptionMetadata.c(WebFilteringOperationDescriptionMetadata.a);
        }
        if (a.j(WebFilteringOperationDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringOperationDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringOperation");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Name", "String");
        a.item("IsUnary", "Boolean");
        a.item("IconName", "String");
        a.item("Hidden", "Boolean");
    };
    WebFilteringOperationDescriptionMetadata.d = function (a) {
        WebFilteringOperationDescriptionMetadata.b(a);
        a.aa("WebFilteringOperation", function () { return new WebFilteringOperationDescription(); });
        a.z("WebFilteringOperation", WebFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringOperationDescriptionMetadata.$t = markType(WebFilteringOperationDescriptionMetadata, 'WebFilteringOperationDescriptionMetadata');
    WebFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringOperationDescriptionMetadata;
}(Base));
export { WebFilteringOperationDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescription } from "./WebFilteringOperationDescription";
/**
 * @hidden
 */
var WebFilteringOperationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringOperationDescriptionMetadata, _super);
    function WebFilteringOperationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringOperationDescriptionMetadata.b = function (a) {
        if (WebFilteringOperationDescriptionMetadata.a == null) {
            WebFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringOperationDescriptionMetadata.c(WebFilteringOperationDescriptionMetadata.a);
        }
        if (a.k(WebFilteringOperationDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringOperationDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringOperation");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Name", "String");
        a.item("IsUnary", "Boolean");
        a.item("IconName", "String");
        a.item("Hidden", "Boolean");
    };
    WebFilteringOperationDescriptionMetadata.d = function (a) {
        WebFilteringOperationDescriptionMetadata.b(a);
        a.ac("WebFilteringOperation", function () { return new WebFilteringOperationDescription(); });
        a.ab("WebFilteringOperation", WebFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringOperationDescriptionMetadata.$t = markType(WebFilteringOperationDescriptionMetadata, 'WebFilteringOperationDescriptionMetadata');
    WebFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringOperationDescriptionMetadata;
}(Base));
export { WebFilteringOperationDescriptionMetadata };
